#!/usr/bin/env python
# -*- coding: utf-8 -*-
# File: wikiseriesbrentlibexceptions.py
#
# Copyright 2023 Brent De Cubber
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to
#  deal in the Software without restriction, including without limitation the
#  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
#  sell copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
#  all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#  DEALINGS IN THE SOFTWARE.
#

"""
Custom exception code for wikiseriesbrentlib.

.. _Google Python Style Guide:
   https://google.github.io/styleguide/pyguide.html

"""

__author__ = '''Brent De Cubber <noneofyabusiness@gmail.com>'''
__docformat__ = '''google'''
__date__ = '''26-04-2023'''
__copyright__ = '''Copyright 2023, Brent De Cubber'''
__credits__ = ["Brent De Cubber"]
__license__ = '''MIT'''
__maintainer__ = '''Brent De Cubber'''
__email__ = '''<noneofyabusiness@gmail.com>'''
__status__ = '''Development'''  # "Prototype", "Development", "Production".
